#include "chartdir.h"
#include <windows.h>
#include "Form1.h"
#include "Form2.h"
#include "Town.h"

#define NUMBER_OF_AGENTS 16348
#define NUMBER_OF_BARS 255
#define PERCENT_CAPACITY 100
#define MAX_ALPHA 100
#define MAX_AGE 100


namespace BARGAME {

	using namespace System;
	using namespace System::ComponentModel;
	using namespace System::Collections;
	using namespace System::Windows::Forms;
	using namespace System::Data;
	using namespace System::Drawing;

public ref class Form1 : public System::Windows::Forms::Form{

public:
	//! \brief Form1 Constructor
	/*!
	* \details Description: Initializes the components of Form1 
	and private variables with default values.
	********************************************************************/
	Form1();
	//! \brief Form1 Destructor
	/*!
	* \details Description: Deletes components of Form1.
	********************************************************************/
	~Form1();

protected:
	//! \brief Array which holds percent based capacities.
	int *percentbarcap1;
//! \brief Array which holds static based capacities.
	int *staticbarcap1;
	//! \brief Integer which holds group size.
	int grpsize;
	//! \brief Integer which holds average age.
	int avgage;
	//! \brief Integer which holds alpha value.
	int alpha;
	//! \brief Form pointer for Form2.
	Form^ form2;
	//! \brief Double which holds number of agents.
	double numagents;
	//! \brief Double which holds number of bars.
	double numbars;

	//! \brief Simulation Button
	/*!
	* \details Description: Button that retrieves user input data and calls Form2's constructor with data.
	* \pre User input data is set and no errors are found.
	* \post Form2 and backend is initialized and new window pops up.
	********************************************************************/
	System::Void button1_Click(System::Object^  sender, System::EventArgs^  e);
	//! \brief Percent Based Radio Button
	/*!
	* \details Description: Radio button that enables corresponding input text box to be enabled/disabled and lets simulation button know if this data should be sent.
	********************************************************************/
	System::Void radioButton1_CheckedChanged(System::Object^  sender, System::EventArgs^  e);
	//! \brief Static Based Radio Button
	/*!
	* \details Description: Radio button that enables corresponding input text box to be enabled/disabled and lets simulation button know if this data should be sent.
	********************************************************************/
	System::Void radioButton2_CheckedChanged(System::Object^  sender, System::EventArgs^  e);
	//! \brief Number of Agents Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox1_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Number of Bars Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox3_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Percent Capacity Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox5_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Static Capacity Error Provider
	/*!
	* \details Description: First tokenizes, then checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox6_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Group Size Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox4_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Alpha Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox7_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Average Age Error Provider
	/*!
	* \details Description: Checks inputted data against pre-set rules.  If inputted data passes, no error is displayed and simulation button is allowed to be enabled given if other error checks pass.  If inputted data fails, a red circle is displayed near text box with description of error and simulation button is disabled.
	* \pre Data is inputted in text box.
	* \post Simulation button is allowed to be enabled.
	********************************************************************/
	System::Void textBox2_Validating(System::Object ^  sender, System::ComponentModel::CancelEventArgs ^  e);
	//! \brief Groups Check Box
	/*!
	* \details Description: Check button that enables corresponding input text box to be enabled/disabled and lets simulation button know if this data should be sent.
	********************************************************************/
	System::Void checkBox3_CheckedChanged_1(System::Object^  sender, System::EventArgs^  e);
	//! \brief Score Dropping Check Box
	/*!
	* \details Description: Check button that enables corresponding input text box to be enabled/disabled and lets simulation button know if this data should be sent
	********************************************************************/
	System::Void checkBox2_CheckedChanged(System::Object^  sender, System::EventArgs^  e);
	//! \brief Mortality Check Box
	/*!
	* \details Description: Check button that enables corresponding input text box to be enabled/disabled and lets simulation button know if this data should be sent.
	********************************************************************/
	System::Void checkBox1_CheckedChanged_1(System::Object^  sender, System::EventArgs^  e);
}
}